@@ -12,9 +12,8 @@ def Sort(nums: List[int]) -> List[int]:
 
 
 def Search(nums: List[int], key: int) -> bool:
-    for nums in nums:
+    for num in nums:
         if num == key:
             return True
 
     return False
-            
\ No newline at end of file
